@@ -377,7 +377,7 @@ def install_base (args):
     sys_conf = au.get_system_conf()
     base_modules = sys_conf.get(constants.base_modules_key,[])
     args = SimpleNamespace(modules=base_modules,
-                            force_data=False,
+                            force_data=args.force_data,
                             version=None,
                             yes=True,
                             private=False,
@@ -461,6 +461,10 @@ parser_install_base.add_argument('-f','--force',
     action='store_true',
     help='Overwrite existing modules',
 )
+parser_install_base.add_argument('-d', '--force-data',
+    action='store_true',
+    help='Download data even if latest data is already installed'
+)
 parser_install_base.set_defaults(func=install_base)
 
 # install
