@@ -104,11 +104,13 @@ function submit () {
         span.textContent = 'Input files are limited to ' + guiInputSizeLimit.toFixed(1) + ' MB.';
         addEl(alertDiv, span);
         addEl(alertDiv,getEl('br'));
-        addEl(alertDiv,getEl('br'));
-        var span = getEl('span');
-        span.textContent = 'The limit can be changed at the settings menu.';
-        addEl(alertDiv, span);
-        addEl(alertDiv,getEl('br'));
+        if (!servermode) {
+            addEl(alertDiv,getEl('br'));
+            var span = getEl('span');
+            span.textContent = 'The limit can be changed at the settings menu.';
+            addEl(alertDiv, span);
+            addEl(alertDiv,getEl('br'));
+        }
         showYesNoDialog(alertDiv, enableSubmitButton, false, true);
     } else {
         commitSubmit();
@@ -516,7 +518,7 @@ function populateJobTr (job) {
         }
         for (var i = 0; i < GLOBALS.reports.valid.length; i++) {
             var reportType = GLOBALS.reports.valid[i];
-            if ((websubmitReportBeingGenerated[job.id] != undefined && websubmitReportBeingGenerated[job.id][reportType] == true) || job.reports.includes(reportType) == true) {
+            if (websubmitReportBeingGenerated[job.id] != undefined && websubmitReportBeingGenerated[job.id][reportType] == true) {
             } else {
                 var option = new Option(reportType, reportType);
                 select.add(option);
